module.exports = defineTest({
	description: 'tracks assigments included via try-catch-deoptimization'
});
